import re

_POWERS = {
	"": 0,
	"k": 1,
	"m": 2,
	"g": 3,
	"t": 4,
	"p": 5,
	"e": 6,
	"z": 7,
	"y": 8,
}
_FORMAT_PATTERN = re.compile("^(\\d+)\\s*([%s]i?|)b?$" % "".join(_POWERS.keys()), flags=re.IGNORECASE)

def _base(suffix):
	# type: (str) -> int
	return 1024 if len(suffix) >= 2 and suffix[1].lower() == "i" else 1000

def _power(suffix):
	# type: (str) -> int
	suffix = suffix[:1]
	return _POWERS[suffix]

class SizeParseError(ValueError):
	pass

def parse(value):
	# type: (str) -> int
	matcher = _FORMAT_PATTERN.match(value)
	if matcher == None:
		raise SizeParseError("Parsing \"%s\" as a byte quantity failed." % value)
	number = int(matcher.group(1))
	suffix = matcher.group(2).lower()
	base = _base(suffix)
	power = _power(suffix)
	return number * (base ** power)



from setuptools import setup

def main():
	setup(
		name="sizeparse",
		version="1.0.0",
		description="A simple Python library for parsing strings denoting byte-capacities with SI or IEC suffixes.",
		license="Unlicense",
		url="https://github.com/chrisgavin/sizeparse",
		packages=["sizeparse"],
		test_suite="tests.get_suite",
		classifiers=[
			"License :: Public Domain",
			"Topic :: Software Development :: Libraries :: Python Modules",
			"Programming Language :: Python :: 2",
			"Programming Language :: Python :: 2.7",
			"Programming Language :: Python :: 3",
			"Programming Language :: Python :: 3.2",
			"Programming Language :: Python :: 3.3",
			"Programming Language :: Python :: 3.4",
			"Programming Language :: Python :: 3.5",
			"Programming Language :: Python :: 3.6",
		],
	)

if __name__ == "__main__":
	main()
